@@ -25,8 +25,9 @@ require Cwd;
 require File::Spec;
 require POSIX;
 
-our $GETCWD = Cwd->getcwd;
+our $CWD = Cwd->getcwd;
 our $MAPSIG = {%SIG};
+our $PATH = $CWD;
 our $PID = $$;
 our $PPID;
 
@@ -109,7 +110,7 @@ sub assertion {
 sub chdir {
   my ($self, $path) = @_;
 
-  $path ||= $GETCWD;
+  $path ||= $CWD;
 
   _chdir($path) or $self->throw('error_on_chdir', $path, $PID, $!)->error;
 
@@ -158,7 +159,7 @@ sub data {
 
   require Venus::Path;
 
-  my $path = Venus::Path->new;
+  my $path = Venus::Path->new($PATH);
 
   $path = $path->child($self->exchange) if $self->exchange;
 
@@ -494,7 +495,7 @@ sub read {
 
   require Venus::Path;
 
-  my $path = Venus::Path->new;
+  my $path = Venus::Path->new($PATH);
 
   $path = $path->child($self->exchange) if $self->exchange;
 
@@ -586,7 +587,7 @@ sub register {
 
   require Venus::Path;
 
-  my $path = Venus::Path->new;
+  my $path = Venus::Path->new($PATH);
 
   $path = $path->child($self->exchange) if $self->exchange;
 
@@ -604,7 +605,7 @@ sub registrants {
 
   require Venus::Path;
 
-  my $path = Venus::Path->new;
+  my $path = Venus::Path->new($PATH);
 
   $path = $path->child($self->exchange) if $self->exchange;
 
@@ -859,7 +860,7 @@ sub write {
 
   require Venus::Path;
 
-  my $path = Venus::Path->new;
+  my $path = Venus::Path->new($PATH);
 
   $path = $path->child($self->exchange) if $self->exchange;
 
@@ -881,7 +882,7 @@ sub unregister {
 
   require Venus::Path;
 
-  my $path = Venus::Path->new;
+  my $path = Venus::Path->new($PATH);
 
   $path = $path->child($self->exchange) if $self->exchange;
 
